==> SyL-0.15.3.tar.gz: SyL/include/lib/SyL_Compress.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Compress.php,v 1.1 2008/08/31 13:58:49 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե饹
 */
require_once 'SyL_File.php';

/** 
 * ̡९饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Compress.php,v 1.1 2008/08/31 13:58:49 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_Compress
{
    /**
     * 󥹥ȥ饯
     *
     * @access private
     */
    function SyL_Compress()
    {
    }

    /**
     * ǡ򰵽̤
     *
     * @static
     * @access public
     * @param string ̥
     * @param string ǡ
     * @param string ¸ե
     * @return string ̸ǡ
     */
    function compress($type, $data, $out_file='')
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'compress'), $data, $out_file);
    }

    /**
     * ե򰵽̤
     *
     * @static
     * @access public
     * @param string ̥
     * @param string оݥե
     * @param string ¸ե
     * @param bool оݥեե饰
     * @return string ̸ǡ
     */
    function compressFromFile($type, $in_file, $out_file='', $in_file_remove=false)
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'compressFromFile'), $in_file, $out_file, $in_file_remove);
    }

    /**
     * ǡह
     *
     * @static
     * @access public
     * @param string ̥
     * @param string ̥ǡ
     * @param string ¸ե
     * @return string ǡ
     */
    function extract($type, $data, $out_file='')
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'extract'), $data, $out_file);
    }

    /**
     * եह
     *
     * @static
     * @access public
     * @param string ̥
     * @param string оݥե
     * @param string ¸ե
     * @param bool оݥեե饰
     * @return string ǡ
     */
    function extractFromFile($type, $in_file, $out_file='', $in_file_remove=false)
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'extractFromFile'), $in_file, $out_file, $in_file_remove);
    }

    /**
     * ǡ򰵽̤å
     *
     * @access protected
     * @param string ǡ
     * @return string ̸ǡ
     */
    function processCompress($data)
    {
    }

    /**
     * ǡहå
     *
     * @access protected
     * @param string ̥ǡ
     * @return string ǡ
     */
    function processExtract($data)
    {
    }

    /**
     * ե뤫ǡ
     *
     * @access public
     * @param string եѥ
     * @return string ե
     */
    function readFile($filename, $protocol='')
    {
        if ($protocol) {
            $protocol .= '://';
        }
        return file_get_contents("{$protocol}{$filename}");
    }

    /**
     * ե˥ǡ¸
     *
     * @access public
     * @param string եѥ
     * @param string ե
     */
    function writeFile($filename, $data)
    {
        $file =& SyL_File::factory('w', $filename);
        $file->process($data);
    }

}

?>

==> SyL-0.15.4.tar.gz: SyL/include/lib/SyL_Compress.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Compress.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե饹
 */
require_once 'SyL_File.php';

/** 
 * ̡९饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Compress.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_Compress
{
    /**
     * 󥹥ȥ饯
     *
     * @access private
     */
    function SyL_Compress()
    {
    }

    /**
     * ǡ򰵽̤
     *
     * @static
     * @access public
     * @param string ̥
     * @param string ǡ
     * @param string ¸ե
     * @return string ̸ǡ
     */
    function compress($type, $data, $out_file='')
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'compress'), $data, $out_file);
    }

    /**
     * ե򰵽̤
     *
     * @static
     * @access public
     * @param string ̥
     * @param string оݥե
     * @param string ¸ե
     * @param bool оݥեե饰
     * @return string ̸ǡ
     */
    function compressFromFile($type, $in_file, $out_file='', $in_file_remove=false)
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'compressFromFile'), $in_file, $out_file, $in_file_remove);
    }

    /**
     * ǡह
     *
     * @static
     * @access public
     * @param string ̥
     * @param string ̥ǡ
     * @param string ¸ե
     * @return string ǡ
     */
    function extract($type, $data, $out_file='')
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'extract'), $data, $out_file);
    }

    /**
     * եह
     *
     * @static
     * @access public
     * @param string ̥
     * @param string оݥե
     * @param string ¸ե
     * @param bool оݥեե饰
     * @return string ǡ
     */
    function extractFromFile($type, $in_file, $out_file='', $in_file_remove=false)
    {
        $classname = 'SyL_Compress' . ucfirst($type);
        include_once dirname(__FILE__) . "/Compress/{$classname}.php";
        return call_user_func(array($classname, 'extractFromFile'), $in_file, $out_file, $in_file_remove);
    }

    /**
     * ǡ򰵽̤å
     *
     * @access protected
     * @param string ǡ
     * @return string ̸ǡ
     */
    function processCompress($data)
    {
    }

    /**
     * ǡहå
     *
     * @access protected
     * @param string ̥ǡ
     * @return string ǡ
     */
    function processExtract($data)
    {
    }

    /**
     * ե뤫ǡ
     *
     * @access public
     * @param string եѥ
     * @return string ե
     */
    function readFile($filename, $protocol='')
    {
        if ($protocol) {
            $protocol .= '://';
        }
        return SyL_File::readContents("{$protocol}{$filename}");
    }

    /**
     * ե˥ǡ¸
     *
     * @access public
     * @param string եѥ
     * @param string ե
     */
    function writeFile($filename, $data)
    {
        SyL_File::writeContents($filename, $data);
    }

}

?>
